body{background:#fff}.no-border{border:none;outline:none}.navbar-brand-zima{display:-webkit-box;display:-ms-flexbox;display:flex;padding:0 0 0 15px;-webkit-box-align:center;-ms-flex-align:center;align-items:center;margin-top:1px}.navbar-brand-zima>img{margin:0 5px 0 0}.navbar-default{background:#304f8c}.navbar-default .navbar-nav>.active>a,.navbar-default .navbar-nav>.active>a:focus,.navbar-default .navbar-nav>.active>a:hover,.navbar-default .navbar-nav>.open>a,.navbar-default .navbar-nav>.open>a:focus,.navbar-default .navbar-nav>.open>a:hover{background:#294479}.navbar-default .navbar-nav>li>a:focus,.navbar-default .navbar-nav>li>a:hover{color:#ef143c}.navbar-default .navbar-nav .open .dropdown-menu>li>a:focus,.navbar-default .navbar-nav .open .dropdown-menu>li>a:hover{color:#ef143c}.navbar-default .navbar-brand:focus,.navbar-default .navbar-brand:hover{color:#ef143c}.navbar-default .navbar-toggle,.navbar-default .navbar-toggle:hover{background:#294479;border-color:#294479}.dropdown-menu{background:#fff}.dropdown-menu .divider{background-color:rgba(41,68,121,.2)}.dropdown-menu>li>a{color:#000}.dropdown-menu>li>a:focus,.dropdown-menu>li>a:hover{background-color:#294479}.top-menu-bar-language-select form{-webkit-box-shadow:none;box-shadow:none}.panel{background:#fff}.panel-default{border-color:#a7bbe1}.panel-default>.panel-heading{background-color:#a7bbe1;border-color:#a7bbe1}.panel-primary{border-color:#375a9f}.panel-primary>.panel-heading{background-color:#375a9f;border-color:#375a9f}.nav-pills>li>a.active{background-color:#335394!important;color:#fff}.nav-pills>li.active>a,.nav-pills>li.active>a:focus,.nav-pills>li.active>a:hover{background-color:#335394}.top-user-menu{color:#000}.nav>li>a:focus,.nav>li>a:hover{background:#fff}