{% load static %}
<link rel="apple-touch-icon" sizes="180x180" href="{% static 'aa_theme_zima/icons/apple-touch-icon.png' %}?v=2">
<link rel="icon" type="image/png" sizes="32x32" href="{% static 'aa_theme_zima/icons/favicon-32x32.png' %}?v=2">
<link rel="icon" type="image/png" sizes="192x192" href="{% static 'aa_theme_zima/icons/android-chrome-192x192.png' %}?v=2">
<link rel="icon" type="image/png" sizes="16x16" href="{% static 'aa_theme_zima/icons/favicon-16x16.png' %}?v=2">
<link rel="shortcut icon" href="{% static 'aa_theme_zima/icons/favicon.ico' %}?v=2">
