{% load static %}
<!DOCTYPE html>
<html lang="en">
    <head>
        <meta charset="utf-8">
        <meta http-equiv="X-UA-Compatible" content="IE=edge">
        <meta name="viewport" content="width=device-width, initial-scale=1">
        <meta name="description" content="">
        <meta name="author" content="">
        <meta property="og:title" content="{{ SITE_NAME }}">
        <meta property="og:image" content="{{ SITE_URL }}{% static 'aa_theme_zima/icons/android-chrome-192x192.png' %}">
        <meta property="og:description" content="Alliance Auth - An auth system for EVE Online to help in-game organizations manage online service access.">

        {% include 'allianceauth/icons.html' %}

        <title>{% block title %}{% block page_title %}{% endblock page_title %} - {{ SITE_NAME }}{% endblock title %}</title>

        {% include 'bundles/bootstrap-css.html' %}
        {% include 'bundles/fontawesome.html' %}
        {% block extra_include %}
        {% endblock %}
        {% if extra_style %}<style>{% block extra_style %}{% endblock %}</style>{% endif %}
        <link rel="stylesheet" href="{% static 'aa_theme_zima/css/login-page.css' %}?v=2">
    </head>
    <body>
        <div class="container w-content">
            {% block content %}
            {% endblock %}
        </div>
    </body>
</html>
