body{background:#090f1a}.no-border{border:none;outline:none}.navbar-brand-zima{display:-webkit-box;display:-ms-flexbox;display:flex;padding:0 0 0 15px;-webkit-box-align:center;-ms-flex-align:center;align-items:center;margin-top:1px}.navbar-brand-zima>img{margin:0 5px 0 0}.navbar-default{background:#1c2f53}.navbar-default .navbar-nav>.active>a,.navbar-default .navbar-nav>.active>a:focus,.navbar-default .navbar-nav>.active>a:hover,.navbar-default .navbar-nav>.open>a,.navbar-default .navbar-nav>.open>a:focus,.navbar-default .navbar-nav>.open>a:hover{background:#0f192d}.navbar-default .navbar-nav>li>a:focus,.navbar-default .navbar-nav>li>a:hover{color:#ef143c}.navbar-default .navbar-nav .open .dropdown-menu>li>a:focus,.navbar-default .navbar-nav .open .dropdown-menu>li>a:hover{color:#ef143c}.navbar-default .navbar-brand:focus,.navbar-default .navbar-brand:hover{color:#ef143c}.navbar-default .navbar-toggle,.navbar-default .navbar-toggle:hover{background:#0f192d;border-color:#0f192d}.dropdown-menu{background:#1c2f53}.dropdown-menu .divider{background-color:rgba(15,25,45,.2)}.dropdown-menu>li>a{color:#f2f2f2}.dropdown-menu>li>a:focus,.dropdown-menu>li>a:hover{background-color:#0f192d}.top-menu-bar-language-select form{-webkit-box-shadow:none;box-shadow:none}.panel{background:#090f1a}.panel-default{border-color:#233a66}.panel-default>.panel-heading{background-color:#233a66;border-color:#233a66}.panel-primary{border-color:#1c2f53}.panel-primary>.panel-heading{background-color:#1c2f53;border-color:#1c2f53}.nav-pills>li>a.active{background-color:#304f8c!important;color:#fff}.nav-pills>li.active>a,.nav-pills>li.active>a:focus,.nav-pills>li.active>a:hover{background-color:#304f8c}.top-user-menu{color:#f2f2f2}.nav>li>a:focus,.nav>li>a:hover{background:#090f1a}