{% extends 'public/base.html' %}

{% load i18n %}

{% block content %}
    <div class="col-md-12">
        {% if messages %}
            {% for message in messages %}
                <div class="alert alert-{{ message.level_tag}}">{{ message }}</div>
            {% endfor %}
        {% endif %}

        <div class="panel panel-default panel-zima">
            <div class="panel-body">
                <div class="col-md-12">
                    {% block middle_box_content %}
                    {% endblock %}
                </div>
            </div>
            {#% include 'public/lang_select.html' %#}
        </div>
    </div>
    <div class="col-md-12 w-footer">
        <ul class="info-ccp">
            <li>
                {% translate "For information on SSO, ESI and security read the <a href=\"https://developers.eveonline.com/blog\" target=\"_blank\" rel=\"noopener noreferrer\">CCP Dev Blog</a>" %}
            </li>
            <li><a href="https://www.eveonline.com/article/introducing-esi" target="_blank" rel="noopener noreferrer">
                {% translate "Introducing ESI - A New API For Eve Online" %}
            </a></li>
            <li><a href="https://community.eveonline.com/support/third-party-applications/" target="_blank" rel="noopener noreferrer">
                {% translate "Manage ESI Applications" %}
            </a></li>
        </ul>
    </div>
{% endblock %}

{% block extra_include %}
    {% include 'bundles/bootstrap-js.html' %}
{% endblock %}
